This package is implementation of multi-criteria decision analysis using topsis.
This package will accept three arguments during file execution:
1. dataset.csv //file which contains the models and parameters
2. string of weights separated by commas(,)
3. string of requirements (+/-) separated by commas(,)
// important
install pandas,sys,operator and math libraries before installing this
//
You can install this package using following command
pip install topsis_aryamank_102003099